@@ -1,4 +1,7 @@
-"""isort:skip_file"""
+""" Analytic computations for scattering
+
+    isort:skip_file
+"""
 from .core import Problem, Solution, create_probem
 from .utils import (
     abs2,
@@ -15,4 +18,4 @@ from .solve_prob import solve_prob
 from .calc_field import sc_field, tt_field
 from .far_field import far_field
 
-__version__ = "1.1.0"
+__version__ = "1.1.1"
